==> geode-wan-1.9.1-sources.jar: org/apache/geode/cache/client/internal/locator/wan/RemoteLocatorPingResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.cache.client.internal.locator.wan;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import org.apache.geode.internal.DataSerializableFixedID;
import org.apache.geode.internal.Version;

public class RemoteLocatorPingResponse implements DataSerializableFixedID {


  /** Used by DataSerializer */
  public RemoteLocatorPingResponse() {
    super();
  }

  @Override
  public void fromData(DataInput in) throws IOException, ClassNotFoundException {}

  @Override
  public void toData(DataOutput out) throws IOException {}



  @Override
  public int getDSFID() {
    return DataSerializableFixedID.REMOTE_LOCATOR_PING_RESPONSE;
  }

  @Override
  public Version[] getSerializationVersions() {
    return null;
  }

}

==> geode-wan-1.15.2-sources.jar: org/apache/geode/cache/client/internal/locator/wan/RemoteLocatorPingResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.cache.client.internal.locator.wan;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import org.apache.geode.internal.serialization.DataSerializableFixedID;
import org.apache.geode.internal.serialization.DeserializationContext;
import org.apache.geode.internal.serialization.KnownVersion;
import org.apache.geode.internal.serialization.SerializationContext;

public class RemoteLocatorPingResponse implements DataSerializableFixedID {


  /** Used by DataSerializer */
  public RemoteLocatorPingResponse() {
    super();
  }

  @Override
  public void fromData(DataInput in,
      DeserializationContext context) throws IOException, ClassNotFoundException {}

  @Override
  public void toData(DataOutput out,
      SerializationContext context) throws IOException {}



  @Override
  public int getDSFID() {
    return DataSerializableFixedID.REMOTE_LOCATOR_PING_RESPONSE;
  }

  @Override
  public KnownVersion[] getSerializationVersions() {
    return null;
  }

}
